.. django-uuidstore documentation master file, created by
   sphinx-quickstart on Sat Oct 11 21:51:41 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to django-uuidstore's documentation!
============================================

Contents:

.. toctree::
   :maxdepth: 2

   install
   intro



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

